rt_construct

Function rt_construct 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn rt_construct( callee: Value, argc: u64, argv: *const Value, ) -> Value
Safety

For nonzero argc, argv must reference argc readable values. Any constructor reached through callee must contain a valid code entry.