#[unsafe(no_mangle)]pub unsafe extern "C" fn rt_globals_init(base: *mut Value, count: u64)
base must be writable for count consecutive, properly aligned values and remain live for the generated program’s execution.
base
count